@@ -1,5 +1,5 @@
 #![deny(rust_2018_idioms)]
-#![allow(clippy::type_complexity, clippy::return_self_not_must_use)]
+#![allow(clippy::type_complexity)]
 
 //! MQTT Client/Server framework
 
@@ -12,6 +12,7 @@ pub mod error;
 pub mod v3;
 pub mod v5;
 
+mod inflight;
 mod io;
 mod server;
 mod service;
