@@ -500,7 +500,7 @@ where
         Box::pin(async move {
             let (hnd, mut delay) = req;
 
-            let result = match select((&*check)(&hnd), &mut delay).await {
+            let result = match select((*check)(&hnd), &mut delay).await {
                 Either::Left(res) => res,
                 Either::Right(_) => return Err(MqttError::HandshakeTimeout),
             };
